@@ -1,6 +1,6 @@
 # Statistics Menu dialogs
 
-# last modified 1 July 04 by J. Fox
+# last modified 3 Jan 05 by J. Fox
 
     # Dimensional-analysis menu
     
@@ -62,17 +62,37 @@ principalComponents <- function(){
             logger("screeplot(.PC)")
             }
         if (addPC == "1") {
-            for(i in 1:nvar){
-                var <- paste("PC", i, sep="")
-                if (is.element(var, .variables)) {
-                    if ("no" == tclvalue(checkReplace(var))) next
+            initializeDialog(subdialog, title="Number of Components")
+            tkgrid(tklabel(subdialog, text="Number of components to retain:", fg="blue"), sticky="w")    
+            sliderFrame <- tkframe(subdialog)
+            sliderValue <- tclVar("1")
+            componentsSlider <- tkscale(sliderFrame, from=1, to=nvar, showvalue=FALSE, variable=sliderValue,
+                resolution=1, orient="horizontal")
+            componentsShow <- tklabel(sliderFrame, textvariable=sliderValue, width=2, justify="right")
+            onOKsub <- function() {
+                if (.grab.focus) tkgrab.release(subdialog)
+                tkdestroy(subdialog)
+                assign(".ncomponents", as.numeric(tclvalue(sliderValue)), envir=.GlobalEnv)
                     }
-                justDoIt(paste(.activeDataSet, "$PC", i, " <- .PC$scores[,", i, "]", sep=""))
-                logger(paste(.activeDataSet, "$PC", i, " <- .PC$scores[,", i, "]", sep=""))
+            subOKCancelHelp()
+            tkgrid(componentsSlider, componentsShow, sticky="nw")
+            tkgrid(sliderFrame, sticky="w")
+            tkgrid(subButtonsFrame, sticky="w")
+            dialogSuffix(subdialog, onOK=onOKsub, rows=2, columns=1, focus=subdialog)
+            if (exists(".ncomponents", envir=.GlobalEnv)){
+                for(i in 1:.ncomponents){
+                    var <- paste("PC", i, sep="")
+                    if (is.element(var, .variables)) {
+                        if ("no" == tclvalue(checkReplace(var))) next
+                        }
+                    justDoIt(paste(.activeDataSet, "$PC", i, " <- .PC$scores[,", i, "]", sep=""))
+                    logger(paste(.activeDataSet, "$PC", i, " <- .PC$scores[,", i, "]", sep=""))
+                    }
+                activeDataSet(.activeDataSet)
+                remove(.ncomponents, envir=.GlobalEnv)
                 }
-            activeDataSet(.activeDataSet)
-            remove(.PC, envir=.GlobalEnv)   
             }
+        remove(.PC, envir=.GlobalEnv)   
         logger("remove(.PC)")
         tkfocus(.commander)
         }
@@ -91,8 +111,6 @@ factorAnalysis <- function(){
     xBox <- variableListBox(top, .numeric, selectmode="multiple", title="Variables (pick three or more)")
     subsetBox()
     optionsFrame <- tkframe(top)
-    nfactorVariable <- tclVar("1")
-    nfactorEntry <- tkentry(optionsFrame, width="2", textvariable=nfactorVariable)
     checkFrame <- tkframe(top)
     radioButtons(checkFrame, name="rotation", buttons=c("noRotate", "varimax", "promax"), 
         values=c("none", "varimax", "promax"), initialValue="varimax", labels=c("None", "Varimax", "Promax"),
@@ -103,7 +121,6 @@ factorAnalysis <- function(){
     onOK <- function(){
         x <- getSelection(xBox)
         nvar <- length(x)
-        nfactor <- as.numeric(tclvalue(nfactorVariable))
         subset <- tclvalue(subsetVariable)
         rotation <- tclvalue(rotationVariable)
         scores <- tclvalue(scoresVariable)
@@ -113,16 +130,31 @@ factorAnalysis <- function(){
             }
         f <- function(k, p) ((p - k)^2 - p - k)^2
         max.factors <- floor(optimize(f, c(0, nvar), tol=.0001, p=nvar)$minimum)
-        if (nfactor > max.factors) {
-            errorCondition(recall=factorAnalysis, message=
-                if (max.factors > 1) paste("Number of factors must be between 1 and ", max.factors, ".", sep="")
-                    else "Number of factors cannot exceed 1.")
-            return()
-            }
+        initializeDialog(subdialog, title="Number of Factors")
+        tkgrid(tklabel(subdialog, text="Number of factors to extract:", fg="blue"), sticky="w")    
+        sliderFrame <- tkframe(subdialog)
+        sliderValue <- tclVar("1")
+        componentsSlider <- tkscale(sliderFrame, from=1, to=max.factors, showvalue=FALSE, variable=sliderValue,
+            resolution=1, orient="horizontal")
+        componentsShow <- tklabel(sliderFrame, textvariable=sliderValue, width=2, justify="right")
+        onOKsub <- function() {
+            if (.grab.focus) tkgrab.release(subdialog)
+            tkdestroy(subdialog)
+            assign(".nfactors", as.numeric(tclvalue(sliderValue)), envir=.GlobalEnv)
+                }
+        subOKCancelHelp()
+        tkgrid(componentsSlider, componentsShow, sticky="nw")
+        tkgrid(sliderFrame, sticky="w")
+        tkgrid(subButtonsFrame, sticky="w")
+        dialogSuffix(subdialog, onOK=onOKsub, rows=2, columns=1, focus=subdialog)
         if (.grab.focus) tkgrab.release(top)
         tkdestroy(top)
+        if (!exists(".nfactors", envir=.GlobalEnv)){
+            tkfocus(.commander)
+            return()
+            }
         subset <- if (trim.blanks(subset) == "<all valid cases>") "" else paste(", subset=", subset, sep="")
-        command <- paste("factanal(~", paste(x, collapse="+"), ", factors=", nfactor, ', rotation="', rotation,
+        command <- paste("factanal(~", paste(x, collapse="+"), ", factors=", .nfactors, ', rotation="', rotation,
             '", scores="', scores, '", data=', .activeDataSet, subset, ")", sep="")
         assign(".FA", justDoIt(command), envir=.GlobalEnv)
         logger(paste(".FA <- ", command, sep=""))
@@ -139,14 +171,12 @@ factorAnalysis <- function(){
             activeDataSet(.activeDataSet)
             }
         logger("remove(.FA)")
-        remove(.FA, envir=.GlobalEnv)
+        remove(.FA, .nfactors, envir=.GlobalEnv)
         tkfocus(.commander)
         }
     OKCancelHelp(helpSubject="factanal")
     tkgrid(getFrame(xBox), sticky="nw")
     tkgrid(subsetFrame, sticky="w")
-    tkgrid(tklabel(optionsFrame, text="Number of factors:"),
-        nfactorEntry, sticky="w")
     tkgrid(optionsFrame, sticky="w")
     tkgrid(rotationFrame, tklabel(checkFrame, text="    "), scoresFrame, sticky="w")
     tkgrid(checkFrame, sticky="w")
